Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(218)

Unified Diff: net/http/http_stream_factory_impl_job_controller.h

Issue 2359803003: Job Controller: clean up metrics logging about the job racing result (Closed)
Patch Set: Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_stream_factory_impl_job_controller.h
diff --git a/net/http/http_stream_factory_impl_job_controller.h b/net/http/http_stream_factory_impl_job_controller.h
index 2c1e0a759938efb3e15888c6bb44bcbefd032049..d0790b6c1c23f18d68f0b96d2194afa4805a6181 100644
--- a/net/http/http_stream_factory_impl_job_controller.h
+++ b/net/http/http_stream_factory_impl_job_controller.h
@@ -241,9 +241,9 @@ class HttpStreamFactoryImpl::JobController
const GURL& url,
ProxyServer* alternative_proxy_server) const;
- // Records histogram metrics for the usage of alternative proxy server. Must
- // be called when |job| has succeeded, and some other jobs will be orphaned.
- void MaybeRecordAlternativeProxyServerUsage(Job* job) const;
+ // Records histogram metrics for the usage of alternative protocol. Must be
+ // called when |job| has succeeded and the other job will be orphaned.
+ void ReportAlternateProtocolUsage(Job* job) const;
// Starts the |alternative_job_|.
void StartAlternativeProxyServerJob();

Powered by Google App Engine
This is Rietveld 408576698